Module types

Module types 

Re-exports from surrealdb-types with the Public* aliases that surrealdb-core uses.

Structs

PublicArray
Represents an array of values in SurrealDB
PublicBytes
Represents binary data in SurrealDB
PublicDatetime
Represents a datetime value in SurrealDB
PublicDuration
Represents a duration value in SurrealDB
PublicFile
Represents a file reference in SurrealDB
PublicObject
Represents an object with key-value pairs in SurrealDB
PublicRange
Represents a range of values in SurrealDB
PublicRecordId
Represents a record identifier in SurrealDB
PublicRecordIdKeyRange
Represents a range of record identifier keys in SurrealDB
PublicRegex
Represents a regular expression in SurrealDB
PublicSet
A set of unique values in SurrealDB
PublicTable
A value type referencing a specific table.
PublicUuid
Represents a UUID value in SurrealDB

Enums

PublicGeometry
Represents geometric shapes in SurrealDB
PublicGeometryKind
Represents different types of geometric shapes in SurrealDB’s type system
PublicKind
The kind of a SurrealDB value.
PublicKindLiteral
Represents literal values in SurrealDB’s type system
PublicNumber
Represents a numeric value in SurrealDB
PublicRecordIdKey
Represents a key component of a record identifier in SurrealDB
PublicValue
Represents a value in SurrealDB