PublicKind

Enum PublicKind 

pub enum PublicKind {
Show 25 variants Any, None, Null, Bool, Bytes, Datetime, Decimal, Duration, Float, Int, Number, Object, String, Uuid, Regex, Table(Vec<Table>), Record(Vec<Table>), Geometry(Vec<GeometryKind>), Either(Vec<Kind>), Set(Box<Kind>, Option<u64>), Array(Box<Kind>, Option<u64>), Function(Option<Vec<Kind>>, Option<Box<Kind>>), Range, Literal(KindLiteral), File(Vec<String>),
}
The kind of a SurrealDB value.

Variants



Any

The most generic type, can be anything.



None

None type.



Null

Null type.



Bool

Boolean type.



Bytes

Bytes type.



Datetime

Datetime type.



Decimal

Decimal type.



Duration

Duration type.



Float

64-bit floating point type.



Int

64-bit signed integer type.



Number

Number type, can be either a float, int or decimal. This is the most generic type for numbers.



Object

Object type.



String

String type.



Uuid

UUID type.



Regex

Regular expression type.



Table(Vec<Table>)

A table type.



Record(Vec<Table>)

A record type.



Geometry(Vec<GeometryKind>)

A geometry type.



Either(Vec<Kind>)

An either type. Can be any of the kinds in the vec.



Set(Box<Kind>, Option<u64>)

A set type.



Array(Box<Kind>, Option<u64>)

An array type.



Function(Option<Vec<Kind>>, Option<Box<Kind>>)

A function type. The first option is the argument types, the second is the optional return type.



Range

A range type.



Literal(KindLiteral)

A literal type. The literal type is used to represent a type that can only be a single value. For example, "a" is a literal type which can only ever be "a". This can be used in the Kind::Either type to represent an enum.



File(Vec<String>)

A file type. If the kind was specified without a bucket the vec will be empty. So <file> is just Kind::File(Vec::new())

Implementations

Source

impl Kind

pub fn flatten(self) -> Vec<Kind>

Recursively flatten a kind into a vector of kinds.

pub fn either(kinds: Vec<Kind>) -> Kind

Create an either kind from a vector of kinds. If after dedeplication the vector is empty, return Kind::None. If after dedeplication the vector has one element, return that element. If after dedeplication the vector has multiple elements, return an Either kind with the elements.

pub fn option(kind: Kind) -> Kind

Create an option kind from a kind.