pub enum PublicKindLiteral {
String(String),
Integer(i64),
Float(f64),
Decimal(Decimal),
Duration(Duration),
Array(Vec<Kind>),
Object(BTreeMap<String, Kind>),
Bool(bool),
}Expand description
Represents literal values in SurrealDB’s type system
Literal types are used to represent specific values that can only be a single value.
For example, a literal type "a" can only ever be the string "a".
This is commonly used in Kind::Either to represent enum-like types.
Variants
String(String)
A string literal
Integer(i64)
An integer literal
Float(f64)
A floating-point literal
Decimal(Decimal)
A decimal literal
Duration(Duration)
A duration literal
Array(Vec<Kind>)
An array of kinds literal
Object(BTreeMap<String, Kind>)
An object with string keys and kind values literal
Bool(bool)
A boolean literal
Implementations