Number

Enum Number 

pub enum Number {
    Int(i64),
    Float(f64),
    Decimal(Decimal),
}
Represents a numeric value in SurrealDB

Numbers in SurrealDB can be integers, floating-point numbers, or decimal numbers. This enum provides type-safe representation for all numeric types.

Variants



Int(i64)

A 64-bit signed integer



Float(f64)

A 64-bit floating-point number



Decimal(Decimal)

A decimal number with arbitrary precision

Implementations

Source

impl Number

pub const NAN: Number

A NaN number

pub fn is_nan(&self) -> bool

Checks if this number is NaN.

pub fn to_int(&self) -> Option<i64>

Converts this number into an i64.

Returns 0 if the number cannot be converted.

pub fn to_f64(&self) -> Option<f64>

Converts this number into an f64.

Returns 0.0 if the number cannot be converted.

Source

impl Number

pub fn kind(&self) -> Kind

Get the kind of number

pub fn is_int(&self) -> bool

Check if this is a of the given type

pub fn into_int(self) -> Result<i64, Error>

Convert this number into the given type

pub fn from_int(v: i64) -> Number

Create a new number from the given type

pub fn is_float(&self) -> bool

Check if this is a of the given type

pub fn into_float(self) -> Result<f64, Error>

Convert this number into the given type

pub fn from_float(v: f64) -> Number

Create a new number from the given type

pub fn is_decimal(&self) -> bool

Check if this is a of the given type

pub fn into_decimal(self) -> Result<Decimal, Error>

Convert this number into the given type

pub fn from_decimal(v: Decimal) -> Number

Create a new number from the given type