pub struct RecordIdKeyRange {
pub start: Bound<RecordIdKey>,
pub end: Bound<RecordIdKey>,
}Expand description
Represents a range of record identifier keys in SurrealDB
This type is used for range queries on record identifiers, allowing queries like “find all records with IDs between X and Y”.
Fields
start: Bound<RecordIdKey>The lower bound of the range
end: Bound<RecordIdKey>The upper bound of the range
Implementations
Sourceimpl RecordIdKeyRange
impl RecordIdKeyRange
Sourcepub fn start(&self) -> Bound<&RecordIdKey>
pub fn start(&self) -> Bound<&RecordIdKey>
Returns the start bound of the range.
Sourcepub fn end(&self) -> Bound<&RecordIdKey>
pub fn end(&self) -> Bound<&RecordIdKey>
Returns the upper bound of the range.
Sourcepub fn into_inner(self) -> (Bound<RecordIdKey>, Bound<RecordIdKey>)
pub fn into_inner(self) -> (Bound<RecordIdKey>, Bound<RecordIdKey>)
Converts this range into the inner bounds.
Sourcepub fn into_value_range(self) -> Range
pub fn into_value_range(self) -> Range
Converts this range into a Range value.
Sourcepub fn from_value_range(range: Range) -> Result<RecordIdKeyRange, Error>
pub fn from_value_range(range: Range) -> Result<RecordIdKeyRange, Error>
Converts a Range value into a RecordIdKeyRange.