pub fn read_surql_file(path: &Path) -> Result<String, String>
Read a .surql file with a size guard.
.surql
Returns an error if the file is larger than MAX_SURQL_FILE_SIZE or cannot be read for any other reason.
MAX_SURQL_FILE_SIZE