pub fn format_source(source: &str, config: &FormatConfig) -> Option<String>Expand description
Format SurrealQL source text using the given config.
Returns Some(formatted) if changes were made, None if the source is already formatted.
pub fn format_source(source: &str, config: &FormatConfig) -> Option<String>Format SurrealQL source text using the given config.
Returns Some(formatted) if changes were made, None if the source is already formatted.