Module schema_lookup

Module schema_lookup 

Structs

FieldType
A field defined in a SurrealQL schema with its type information.
FunctionParam
A parameter defined in a SurrealQL DEFINE FUNCTION statement.

Functions

collect_field_types
Collect all field types for all tables from .surql files under schema_dir.
find_field_type
Find the type of a specific field on a table, scanning .surql files under schema_dir.
find_function_params
Find a DEFINE FUNCTION by name and return its parameters.