Module fmt

Module fmt 

SurrealQL formatting utilities.

Structs

CoverStmts
EscapeIdent
Escapes identifiers which might be used in the same place as a keyword.
EscapeKwFreeIdent
Escapes identifiers which can never be used in the same place as a keyword.
EscapeKwIdent
EscapeObjectKey
EscapeRidKey
Float
Fmt
Implements ToSql by calling formatter on contents.
QuoteStr

Functions

fmt_separated_by
Creates a formatting function that joins iterators with an arbitrary separator.