pub struct EscapeKwFreeIdent<'a>(pub &'a str);Expand description
Escapes identifiers which can never be used in the same place as a keyword.
Examples of this is a Param as ‘$’ is in front of the identifier so it cannot be an
Tuple Fields
0: &'a strTrait Implementations
Sourceimpl ToSql for EscapeKwFreeIdent<'_>
impl ToSql for EscapeKwFreeIdent<'_>