pub struct Fmt<T, F> { /* private fields */ }Expand description
Implements ToSql by calling formatter on contents.
Implementations
Sourceimpl<I: IntoIterator<Item = T>, T: ToSql> Fmt<I, fn(I, &mut String, SqlFormat)>
impl<I: IntoIterator<Item = T>, T: ToSql> Fmt<I, fn(I, &mut String, SqlFormat)>
Sourcepub fn comma_separated(into_iter: I) -> Self
pub fn comma_separated(into_iter: I) -> Self
Formats values with a comma and a space separating them.
Sourcepub fn verbar_separated(into_iter: I) -> Self
pub fn verbar_separated(into_iter: I) -> Self
Formats values with a verbar and a space separating them.
Sourcepub fn pretty_comma_separated(into_iter: I) -> Self
pub fn pretty_comma_separated(into_iter: I) -> Self
Formats values with a comma and a space separating them or, if pretty printing is in effect, a comma, a newline, and indentation.
Sourcepub fn one_line_separated(into_iter: I) -> Self
pub fn one_line_separated(into_iter: I) -> Self
Formats values with a new line separating them.