pub struct Lookup {
pub kind: LookupKind,
pub expr: Option<Fields>,
pub what: Vec<LookupSubject>,
pub cond: Option<Cond>,
pub split: Option<Splits>,
pub group: Option<Groups>,
pub order: Option<Ordering>,
pub limit: Option<Limit>,
pub start: Option<Start>,
pub alias: Option<Idiom>,
}Expand description
A lookup is a unified way of looking up graph edges and record references. Since they both work very similarly, they also both support the same operations
Fields
kind: LookupKindexpr: Option<Fields>what: Vec<LookupSubject>cond: Option<Cond>split: Option<Splits>group: Option<Groups>order: Option<Ordering>limit: Option<Limit>start: Option<Start>alias: Option<Idiom>Trait Implementations
impl Eq for Lookup
impl StructuralPartialEq for Lookup