Module syn

Module syn 

Module containing the implementation of the surrealql tokens, lexer, and parser.

Re-exports

pub use parser::ParserSettings;

Modules

error
lexer
parser
Module implementing the SurrealQL parser.
token
Module specifying the token representation of the parser.

Functions

block
Parse a block, expects the value to be wrapped in {}.
could_be_reserved_keyword
Takes a string and returns if it could be a reserved keyword in certain contexts.
datetime
Parse a datetime without enclosing delimiters from a string.
duration
Parse a duration from a string.
expr
Parses a SurrealQL Expr.
expr_legacy_strand
Parses a SurrealQL [Value] and parses values within strings.
expr_with_capabilities
Parses a SurrealQL [Value].
function
Parses a SurrealQL function name.
function_with_capabilities
Parses a SurrealQL function name.
idiom
Parses a SurrealQL Idiom
json
Parses JSON into an inert SurrealQL PublicValue.
json_legacy_strand
Parses JSON into an inert SurrealQL PublicValue and parses values within strings.
kind
Parse a kind from a string.
parse
Parses a SurrealQL query.
parse_with
parse_with_capabilities
Parses a SurrealQL query.
parse_with_settings
record_id
Parse a record id.
settings_from_capabilities
Creates the parser settings struct from the global configuration values as wel as the capabilities struct.
table
Parse a table name from a string.
value
Parses a SurrealQL PublicValue and parses values within strings.
value_legacy_strand
Parses a SurrealQL PublicValue and parses values within strings.