pub struct RenderedError {
pub errors: Vec<String>,
pub snippets: Vec<Snippet>,
}Fields
errors: Vec<String>snippets: Vec<Snippet>Implementations
Sourceimpl RenderedError
impl RenderedError
Sourcepub fn offset_location(self, line: usize, col: usize) -> Self
pub fn offset_location(self, line: usize, col: usize) -> Self
Offset the snippet locations within the rendered error by a given number of lines and columns.
The column offset is only applied to the any snippet which is at line 1