pub struct Lexer<'a> { /* private fields */ }Expand description
The SurrealQL lexer. Takes a slice of bytes and turns it into tokens. The lexer is designed with possible invalid utf-8 in mind and will handle bytes which are invalid utf-8 with an error.
The lexer generates tokens lazily. whenever Lexer::next_token is called
on the lexer it will try to lex the next bytes in the give source as a
token. The lexer always returns a token, even if the source contains invalid
tokens or as at the end of the source. In both cases a specific
type of token is returned.
Note that SurrealQL syntax cannot be lexed in advance. For example, record strings and regexes, both cannot be parsed correctly without knowledge of previous tokens as they are both ambigious with other tokens.
Implementations
Sourceimpl Lexer<'_>
impl Lexer<'_>
Sourcepub fn lex_compound<F, R>(
&mut self,
start: Token,
f: F,
) -> Result<CompoundToken<R>, SyntaxError>
pub fn lex_compound<F, R>( &mut self, start: Token, f: F, ) -> Result<CompoundToken<R>, SyntaxError>
Lex a more complex token from the start token. The start token should already be consumed.
Sourceimpl Lexer<'_>
impl Lexer<'_>
pub fn unescape_ident_span<'a>( str: &'a str, span: Span, buffer: &'a mut Vec<u8>, ) -> Result<&'a str, SyntaxError>
Sourceimpl Lexer<'_>
impl Lexer<'_>
Sourcepub fn lex_datetime(str: &str) -> Result<PublicDatetime, SyntaxError>
pub fn lex_datetime(str: &str) -> Result<PublicDatetime, SyntaxError>
Lex a datetime from a string.
Sourceimpl Lexer<'_>
impl Lexer<'_>
Sourcepub fn unescape_string_span<'a>(
str: &str,
span: Span,
buffer: &'a mut Vec<u8>,
) -> Result<&'a str, SyntaxError>
pub fn unescape_string_span<'a>( str: &str, span: Span, buffer: &'a mut Vec<u8>, ) -> Result<&'a str, SyntaxError>
Unescapes a string slice. Expects a string and the span of that string within the source code where the string contains the full string token, including possible prefix digit and qoutes.
Note that the string token can contain invalid escape sequences which will be properly reported as errors by this function.
Returns the actual unescaped value of the string.
Will panic if it is not a string slice.
Sourcepub fn unescape_regex_span<'a>(
str: &str,
span: Span,
buffer: &'a mut Vec<u8>,
) -> Result<&'a str, SyntaxError>
pub fn unescape_regex_span<'a>( str: &str, span: Span, buffer: &'a mut Vec<u8>, ) -> Result<&'a str, SyntaxError>
Unescapes a regex slice. Expects a string and the span of that string within the source code where the string contains the full string token, including possible prefix digit and qoutes.
Note that the string token can contain invalid escape sequences which will be properly reported as errors by this function.
Returns the actual unescaped value of the regex.
Will panic if it is not a regex slice.
Sourcepub fn escaped_string_offset(escaped_str: &str, offset: u32) -> u32
pub fn escaped_string_offset(escaped_str: &str, offset: u32) -> u32
Returns the offset within a string from the offset within the escaped string.
For instance given the string a\rb and the offset 2 this function will return 3 as
the 2 index in the resulting string as from index 3 in the source string.
Panic
Assumes the escaped string is valid string including valid escape squences. if the string is not valid it will panic.
pub fn lex_uuid(str: &str) -> Result<PublicUuid, SyntaxError>
Sourcepub fn lex_bytes(str: &str) -> Result<PublicBytes, SyntaxError>
pub fn lex_bytes(str: &str) -> Result<PublicBytes, SyntaxError>
Lex a bytes string.
pub fn lex_file(str: &str) -> Result<PublicFile, SyntaxError>
Sourceimpl<'a> Lexer<'a>
impl<'a> Lexer<'a>
Sourcepub fn change_source<'b>(self, source: &'b [u8]) -> Lexer<'b> ⓘ
pub fn change_source<'b>(self, source: &'b [u8]) -> Lexer<'b> ⓘ
Change the used source from the lexer to a new buffer.
Usefull for reusing buffers.
Panic
This function will panic if the source is longer then u32::MAX.
Sourcepub fn next_token(&mut self) -> Token
pub fn next_token(&mut self) -> Token
Returns the next token, driving the lexer forward.
If the lexer is at the end the source it will always return the Eof token.
pub fn current_span(&self) -> Span
pub fn span_since(&self, offset: u32) -> Span
Sourcepub fn backup_after(&mut self, span: Span)
pub fn backup_after(&mut self, span: Span)
Moves the lexer state to after the give span.
Warning
Moving the lexer into a state where the next byte is within a multibyte character will result in spurious errors.
Sourcepub fn span_str(&self, span: Span) -> &'a str
pub fn span_str(&self, span: Span) -> &'a str
Returns the string for a given span of the source. Will panic if the given span was not valid for the source, or invalid utf8
Sourcepub fn span_bytes(&self, span: Span) -> &'a [u8] ⓘ
pub fn span_bytes(&self, span: Span) -> &'a [u8] ⓘ
Returns the string for a given span of the source. Will panic if the given span was not valid for the source, or invalid utf8
Sourcepub fn assert_finished(&self) -> Result<(), SyntaxError>
pub fn assert_finished(&self) -> Result<(), SyntaxError>
Returns an error if not all bytes were consumed.