pub struct ParserSettings {
pub legacy_strands: bool,
pub flexible_record_id: bool,
pub object_recursion_limit: usize,
pub query_recursion_limit: usize,
pub files_enabled: bool,
pub surrealism_enabled: bool,
}Fields
legacy_strands: boolParse strand like the old parser where a strand which looks like a UUID, Record-Id, Or a DateTime will be parsed as a date-time.
flexible_record_id: boolSet whether to allow record-id’s which don’t adheare to regular ident
rules. Setting this to true will allow parsing of, for example,
foo:0bar. This would be rejected by normal identifier rules as most
identifiers can’t start with a number.
object_recursion_limit: usizeDisallow a query to have objects deeper that limit.
Arrays also count towards objects. So [{foo: [] }] would be 3 deep.
query_recursion_limit: usizeDisallow a query from being deeper than the give limit. A query recurses when a statement contains another statement within itself. Examples are subquery and blocks like block statements and if statements and such.
files_enabled: boolWhether the files feature is enabled
surrealism_enabled: boolWhether the surrealism feature is enabled
Implementations
Sourceimpl ParserSettings
impl ParserSettings
pub fn default_with_experimental(enabled: bool) -> Self