pub enum TokenKind {
Show 32 variants
Keyword(Keyword),
Algorithm(Algorithm),
Language(Language),
Distance(DistanceKind),
VectorType(VectorTypeKind),
Operator(Operator),
OpenDelim(Delim),
CloseDelim(Delim),
String(StringKind),
Parameter,
Identifier,
LeftChefron,
RightChefron,
Star,
Question,
Dollar,
ArrowRight,
ForwardSlash,
Dot,
DotDot,
DotDotDot,
SemiColon,
PathSeperator,
Colon,
Comma,
Vert,
At,
Eof,
Digits,
NaN,
Infinity,
Invalid,
}Expand description
The type of token
Variants
Keyword(Keyword)
Algorithm(Algorithm)
Language(Language)
Distance(DistanceKind)
VectorType(VectorTypeKind)
Operator(Operator)
OpenDelim(Delim)
CloseDelim(Delim)
String(StringKind)
a token denoting the opening of a string, i.e. r"
Parameter
A parameter like $name.
Identifier
LeftChefron
<
RightChefron
>
Star
*
Question
?
Dollar
$
ArrowRight
->
ForwardSlash
‘/’
Dot
.
DotDot
..
DotDotDot
... or …
SemiColon
;
PathSeperator
::
Colon
:
Comma
,
Vert
|
At
@
Eof
A token which indicates the end of the file.
Digits
A token consiting of one or more ascii digits.
NaN
The Not-A-Number number token.
Infinity
The infinity number token.
Invalid
A token which could not be properly lexed.
Implementations