Re-exports from surrealdb-types matching crate::val::* paths in upstream code.
Modules
Structs
- Array
- Represents an array of values in SurrealDB
- Bytes
- Represents binary data in SurrealDB
- Datetime
- Represents a datetime value in SurrealDB
- Decimal
Decimalrepresents a 128 bit representation of a fixed-precision decimal number. The finite set of values of typeDecimalare of the form m / 10e, where m is an integer such that -296 < m < 296, and e is an integer between 0 and 28 inclusive.- Duration
- Represents a duration value in SurrealDB
- File
- Represents a file reference in SurrealDB
- Object
- Represents an object with key-value pairs in SurrealDB
- Range
- Represents a range of values in SurrealDB
- Record
Id - Represents a record identifier in SurrealDB
- Record
IdKey Range - Represents a range of record identifier keys in SurrealDB
- Regex
- Represents a regular expression in SurrealDB
- Set
- A set of unique values in SurrealDB
- Table
- A value type referencing a specific table.
- Table
Name - TableName newtype
- Uuid
- Represents a UUID value in SurrealDB
Enums
- Geometry
- Represents geometric shapes in SurrealDB
- Geometry
Kind - Represents different types of geometric shapes in SurrealDB’s type system
- Number
- Represents a numeric value in SurrealDB
- Record
IdKey - Represents a key component of a record identifier in SurrealDB
- Value
- Represents a value in SurrealDB
Traits
- Decimal
Ext - Decimal extension trait