pub enum Expr {
Show 33 variants
Literal(Literal),
Param(Param),
Idiom(Idiom),
Table(String),
Mock(Mock),
Block(Box<Block>),
Constant(Constant),
Prefix {
op: PrefixOperator,
expr: Box<Expr>,
},
Postfix {
expr: Box<Expr>,
op: PostfixOperator,
},
Binary {
left: Box<Expr>,
op: BinaryOperator,
right: Box<Expr>,
},
FunctionCall(Box<FunctionCall>),
Closure(Box<Closure>),
Break,
Continue,
Throw(Box<Expr>),
Return(Box<OutputStatement>),
IfElse(Box<IfelseStatement>),
Select(Box<SelectStatement>),
Create(Box<CreateStatement>),
Update(Box<UpdateStatement>),
Delete(Box<DeleteStatement>),
Relate(Box<RelateStatement>),
Insert(Box<InsertStatement>),
Define(Box<DefineStatement>),
Remove(Box<RemoveStatement>),
Rebuild(Box<RebuildStatement>),
Upsert(Box<UpsertStatement>),
Alter(Box<AlterStatement>),
Info(Box<InfoStatement>),
Foreach(Box<ForeachStatement>),
Let(Box<SetStatement>),
Sleep(Box<SleepStatement>),
Explain {
format: ExplainFormat,
analyze: bool,
statement: Box<Expr>,
},
}Variants
Literal(Literal)
Param(Param)
Idiom(Idiom)
Table(String)
Mock(Mock)
Block(Box<Block>)
Constant(Constant)
Prefix
Postfix
Binary
FunctionCall(Box<FunctionCall>)
Closure(Box<Closure>)
Break
Continue
Throw(Box<Expr>)
Return(Box<OutputStatement>)
IfElse(Box<IfelseStatement>)
Select(Box<SelectStatement>)
Create(Box<CreateStatement>)
Update(Box<UpdateStatement>)
Delete(Box<DeleteStatement>)
Relate(Box<RelateStatement>)
Insert(Box<InsertStatement>)
Define(Box<DefineStatement>)
Remove(Box<RemoveStatement>)
Rebuild(Box<RebuildStatement>)
Upsert(Box<UpsertStatement>)
Alter(Box<AlterStatement>)
Info(Box<InfoStatement>)
Foreach(Box<ForeachStatement>)
Let(Box<SetStatement>)
Sleep(Box<SleepStatement>)
Explain
Implementations
Sourceimpl Expr
impl Expr
pub fn to_idiom(&self) -> Idiom
pub fn from_public_value(value: PublicValue) -> Self
Sourcepub fn needs_parentheses(&self) -> bool
pub fn needs_parentheses(&self) -> bool
Returns if this expression needs to be parenthesized when inside another expression.
Sourcepub fn has_left_none_null(&self) -> bool
pub fn has_left_none_null(&self) -> bool
Returns true if there is a NONE or NULL value in the left most spot when formatting.
returns true for NONE + 1, NULL(), NONE, NULL.. etc.
Required for proper formatting when NONE can conflict with a clause.
pub fn has_left_minus(&self) -> bool
pub fn has_left_idiom(&self) -> bool