Structs
- Lookup
- A lookup is a unified way of looking up graph edges and record references. Since they both work very similarly, they also both support the same operations
Enums
- Lookup
Kind - This enum instructs whether the lookup is a graph edge or a record reference
- Lookup
Subject - This enum instructs whether we scan all edges on a table or just a specific range