Module containing the implementation of the surrealql tokens, lexer, and parser.
Re-exports
pub use parser::ParserSettings;
Modules
- error
- lexer
- parser
- Module implementing the SurrealQL parser.
- token
- Module specifying the token representation of the parser.
Functions
- block
- Parse a block, expects the value to be wrapped in
{}. - could_
be_ reserved_ keyword - Takes a string and returns if it could be a reserved keyword in certain contexts.
- datetime
- Parse a datetime without enclosing delimiters from a string.
- duration
- Parse a duration from a string.
- expr
- Parses a SurrealQL
Expr. - expr_
legacy_ strand - Parses a SurrealQL [
Value] and parses values within strings. - expr_
with_ capabilities - Parses a SurrealQL [
Value]. - function
- Parses a SurrealQL function name.
- function_
with_ capabilities - Parses a SurrealQL function name.
- idiom
- Parses a SurrealQL
Idiom - json
- Parses JSON into an inert SurrealQL
PublicValue. - json_
legacy_ strand - Parses JSON into an inert SurrealQL
PublicValueand parses values within strings. - kind
- Parse a kind from a string.
- parse
- Parses a SurrealQL query.
- parse_
with - parse_
with_ capabilities - Parses a SurrealQL query.
- parse_
with_ settings - record_
id - Parse a record id.
- settings_
from_ capabilities - Creates the parser settings struct from the global configuration values as wel as the capabilities struct.
- table
- Parse a table name from a string.
- value
- Parses a SurrealQL
PublicValueand parses values within strings. - value_
legacy_ strand - Parses a SurrealQL
PublicValueand parses values within strings.