pub fn parse(input: &str) -> Result<Ast>Expand description
Parses a SurrealQL query.
During query parsing, the total depth of calls to parse values (including arrays, expressions, functions, objects, sub-queries), Javascript values, and geometry collections count against a computation depth limit. If the limit is reached, parsing will return an error, as opposed to spending more time and potentially overflowing the call stack.
If you encounter this limit and believe that it should be increased, please open an issue!